pub struct Help(pub String);Expand description
An actionable help suggestion.
Helps appear as footer messages and suggest specific actions the user can take to resolve the issue.
Tuple Fields
0: StringImplementations