pub struct Note(pub String);Expand description
An informational note providing context.
Notes appear as footer messages and explain why something happened or provide additional context about the diagnostic.
Tuple Fields
0: StringImplementations