#[non_exhaustive]pub enum PreviewFeature {
TestInfra,
}Expand description
A preview feature that can be enabled with --preview.
Preview features are in-progress language additions that:
- May change or be removed before stabilization
- Require explicit opt-in via
--preview <feature> - Allow incremental implementation to be merged to main
See ADR-0005 for the full design.
When all preview features are stabilized, this enum may be empty. New preview features are added here as development begins.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
TestInfra
Testing infrastructure feature - permanently unstable. Used to verify the preview feature gating mechanism works.
Implementations
Sourceimpl PreviewFeature
impl PreviewFeature
Sourcepub fn all() -> &'static [PreviewFeature]
pub fn all() -> &'static [PreviewFeature]
Get all available preview features.